/*=======================================================================
  Module: demo.protected
=======================================================================*/ 

set sqlblanklines on

----------------------------------------------------------------------------
-- cleanup
----------------------------------------------------------------------------
begin
  ORDS.delete_privilege( p_name => 'demo.protected');
  ORDS.delete_role( p_role_name => 'HR Administrator');
  -- delete module if exists
--  ords.delete_module( p_module_name => 'demo.protected');
end;
/

declare
  l_moduleid   number;
  l_templateid number;
  l_handlerid  number;
  l_module_name user_ords_modules.name%type := 'demo.protected';
  l_pattern user_ords_templates.uri_template%type;
begin
  -- delete module if exists
  ords.delete_module( p_module_name => l_module_name);
  
  -- create module
  ords.define_module(
    p_module_name       => l_module_name
   ,p_base_path => 'demo-protected/'
   ,p_status     => 'PUBLISHED'
  );

  ----------------------------------------------------------------------------
  -- HANDLER departments/ 
  ----------------------------------------------------------------------------
  l_pattern := 'departments/';
  ords.define_template(
    p_module_name    => l_module_name
   ,p_pattern => l_pattern
  );

  --------------------------------------
  -- GET departments/ 
  --------------------------------------
  ords.define_handler(
    p_module_name       => l_module_name
   ,p_pattern => l_pattern
   ,p_source_type  => ords.source_type_collection_feed
   ,p_source       => q'[
   
   select :current_user,
          deptno "$self", 
          dept.* 
     from dept
   
   ]'
   ,p_method       => 'GET'
   ,p_items_per_page => 100
  );  
  
end;
/

declare
  l_roles    owa.vc_arr;
  l_patterns owa.vc_arr;
  l_modules  owa.vc_arr;
begin
  ----------------------------------------------------------------------------
  -- cleanup
  ----------------------------------------------------------------------------
  ORDS.delete_privilege( p_name => 'demo.protected');
  ORDS.delete_role( p_role_name => 'HR Administrator');

  ----------------------------------------------------------------------------
  -- create role
  ----------------------------------------------------------------------------
  ORDS.CREATE_ROLE( p_role_name => 'HR Administrator');
  
  ----------------------------------------------------------------------------
  -- protect module
  ----------------------------------------------------------------------------
  l_roles(1) := 'HR Administrator';

  -- Liste der URL-Patterns, die geschützt werden sollen.
  --l_patterns(1) := '/emp/list/*';
  l_modules(1) := 'demo.protected';
  ords.define_privilege(
    p_privilege_name => 'demo.protected'
   ,p_roles =>          l_roles
   ,p_patterns =>       l_patterns     
   ,p_modules =>        l_modules      
   ,p_description =>    'only users with role HR Administrator are allowed'
   ,p_label =>          'Demo Privilege'
  );
  
  commit;
end;
/



/*
  source_type_query           CONSTANT ords_handlers.source_type%type := 'json/query';
  source_type_csv_query       CONSTANT ords_handlers.source_type%type := 'csv/query';
  source_type_query_one_row   CONSTANT ords_handlers.source_type%type := 'json/query;type=single';
  source_type_feed            CONSTANT ords_handlers.source_type%type := 'json/query;type=feed';
  source_type_media           CONSTANT ords_handlers.source_type%type := 'resource/lob';
  source_type_plsql           CONSTANT ords_handlers.source_type%type := 'plsql/block';
  source_type_collection_feed CONSTANT ords_handlers.source_type%type := 'json/collection';
  source_type_collection_item CONSTANT ords_handlers.source_type%type := 'json/item';
*/




commit
/
/*


select * from all_objects where owner='ORDS_METADATA'
and object_type='VIEW';

select * from user_ords_services;
select * from all_ords_services;

select * from user_ords_modules;
select * from all_ords_modules;


*/